window.Gleam.initSearch([{"doc":"priorityq","title":"priorityq","content":"# priorityq\n\n[![Package Version](https://img.shields.io/hexpm/v/priorityq)](https://hex.pm/packages/priorityq)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/priorityq/)\n\nA priority queue implementation based on max [pairing heaps](https://www.cs.cmu.edu/~sleator/papers/pairing-heaps.pdf). Written in pure Gleam.\n\n## Installation\n\nAdd `priorityq` to your Gleam project\n\n```sh\ngleam add priorityq\n```\n\n## Usage\n\n```gleam\nimport gleam/int\nimport priorityq\n\npub fn main() {\n  priorityq.new(int.compare) |&gt; priorityq.is_empty // -&gt; True\n\n  let pq = priorityq.from_list([1, 5], int.compare)\n  pq |&gt; priorityq.push(10) |&gt; priorityq.peek // -&gt; 10\n  pq |&gt; priorityq.pop |&gt; priorityq.size // -&gt; 1\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/priorityq&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"priorityq","title":"PriorityQueue","content":"pub opaque type PriorityQueue(t)\n A priority queue implemented with a max pairing heap.\n\n\nSynonyms:\npriorityq.PriorityQueue\npriorityq PriorityQueue","url":"priorityq.html#PriorityQueue"},{"doc":"priorityq","title":"from_list","content":"pub fn from_list(\n  ls: List(a),\n  cmp: fn(a, a) -&gt; Order,\n) -&gt; PriorityQueue(a)\n Creates a priority queue from a list.\n\n Runs in linear time.\n\n ## Examples\n\n \n import gleam/int\n\n from_list([1, 10, 5], int.compare) // -&gt; PriorityQueue(Int)\n \n\nSynonyms:\npriorityq.from_list\npriorityq from_list","url":"priorityq.html#from_list"},{"doc":"priorityq","title":"is_empty","content":"pub fn is_empty(pq: PriorityQueue(a)) -&gt; Bool\n Returns whether the priority queue is empty.\n\n Runs in constant time.\n\n ## Examples\n\n \n import gleam/int\n\n new(int.compare) |&gt; is_empty // -&gt; True\n from_list([0], int.compare) |&gt; is_empty // -&gt; False\n \n\nSynonyms:\npriorityq.is_empty\npriorityq is_empty","url":"priorityq.html#is_empty"},{"doc":"priorityq","title":"new","content":"pub fn new(cmp: fn(a, a) -&gt; Order) -&gt; PriorityQueue(a)\n Creates an empty priority queue.\n\n ## Examples\n\n \n import gleam/int\n\n new(int.compare) // -&gt; PriorityQueue(Int)\n \n\nSynonyms:\npriorityq.new\npriorityq new","url":"priorityq.html#new"},{"doc":"priorityq","title":"peek","content":"pub fn peek(pq: PriorityQueue(a)) -&gt; Option(a)\n Returns the maximum value in the priority queue.\n\n ## Examples\n\n \n import gleam/int\n\n new(int.compare) |&gt; peek // -&gt; None\n from_list([1, 10, 5], int.compare) |&gt; peek // -&gt; 10\n \n\nSynonyms:\npriorityq.peek\npriorityq peek","url":"priorityq.html#peek"},{"doc":"priorityq","title":"pop","content":"pub fn pop(pq: PriorityQueue(a)) -&gt; PriorityQueue(a)\n Pops the maximum value from the priority queue.\n\n Runs in amortized logarithmic time.\n\n ## Examples\n\n \n import gleam/int\n\n from_list([0], int.compare) |&gt; pop // -&gt; PriorityQueue(Int)\n \n\nSynonyms:\npriorityq.pop\npriorityq pop","url":"priorityq.html#pop"},{"doc":"priorityq","title":"push","content":"pub fn push(pq: PriorityQueue(a), val: a) -&gt; PriorityQueue(a)\n Pushes a value into the priority queue.\n\n Runs in constant time.\n\n ## Examples\n\n \n import gleam/int\n\n new(int.compare) |&gt; push(10) // -&gt; PriorityQueue(Int)\n \n\nSynonyms:\npriorityq.push\npriorityq push","url":"priorityq.html#push"},{"doc":"priorityq","title":"size","content":"pub fn size(pq: PriorityQueue(a)) -&gt; Int\n Returns the number of elements in the priority queue.\n\n Runs in constant time.\n\n ## Examples\n\n \n import gleam/int\n\n from_list([1, 2, 3], int.compare) |&gt; size // -&gt; 3\n \n\nSynonyms:\npriorityq.size\npriorityq size","url":"priorityq.html#size"},{"doc":"priorityq","title":"priorityq","content":"","url":"priorityq.html"}]);